@@ -20,7 +20,10 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <giomm/actiongroup.h>
 #include <giomm/appinfo.h>
+#include <giomm/application.h>
+#include <giomm/applicationcommandline.h>
 #include <giomm/asyncresult.h>
 #include <giomm/bufferedinputstream.h>
 #include <giomm/bufferedoutputstream.h>
@@ -28,6 +31,18 @@
 #include <giomm/contenttype.h>
 #include <giomm/datainputstream.h>
 #include <giomm/dataoutputstream.h>
+#include <giomm/dbusaddress.h>
+#include <giomm/dbusauthobserver.h>
+#include <giomm/dbusconnection.h>
+#include <giomm/dbuserror.h>
+#include <giomm/dbusintrospection.h>
+#include <giomm/dbusmessage.h>
+#include <giomm/dbusmethodinvocation.h>
+#include <giomm/dbusownname.h>
+#include <giomm/dbusproxy.h>
+#include <giomm/dbusserver.h>
+#include <giomm/dbusutils.h>
+#include <giomm/dbuswatchname.h>
 #ifndef G_OS_WIN32
 # include <giomm/desktopappinfo.h>
 #endif
@@ -64,6 +79,8 @@
 #include <giomm/networkaddress.h>
 #include <giomm/networkservice.h>
 #include <giomm/outputstream.h>
+#include <giomm/proxy.h>
+#include <giomm/proxyresolver.h>
 #include <giomm/resolver.h>
 #include <giomm/seekable.h>
 #include <giomm/settings.h>
@@ -73,13 +90,18 @@
 #include <giomm/socketclient.h>
 #include <giomm/socketconnectable.h>
 #include <giomm/socketconnection.h>
+#include <giomm/socketcontrolmessage.h>
 #include <giomm/srvtarget.h>
 #include <giomm/tcpconnection.h>
 #include <giomm/themedicon.h>
 #ifndef G_OS_WIN32
 # include <giomm/unixconnection.h>
+# include <giomm/unixcredentialsmessage.h>
+# include <giomm/unixfdlist.h>
+# include <giomm/unixfdmessage.h>
 # include <giomm/unixinputstream.h>
 # include <giomm/unixoutputstream.h>
+# include <giomm/unixsocketaddress.h>
 #endif
 #include <giomm/volume.h>
 #include <giomm/volumemonitor.h>
